data_transform_hurs <- function(tas, tdps){
    # obtain relative humidity (in %; tas and tdps need to be in C)
    # ref: https://www.osti.gov/servlets/purl/548871&lang=en
    #   Alduchov OA, Eskridge RE. 
    #   Improved Magnus form approximation of saturation vapor pressure. 
    #   Journal of Applied Meteorology and Climatology. 1996 Apr;35(4):601-9

    b = 17.625
    c = 243.04
    hurs <- tas # for metadata (lon, lat, and attrs$Dates)
    hurs$data <- 100*exp(b * c * (tdps$data - tas$data) / ((c + tdps$data) * (c + tas$data)))
    hurs$attrs$Units <- '%'

    return(hurs) # metadata: coords and dates
}